@@ -1,5 +1,9 @@
-////////////////////////////////////////////
-/// CHOICE
+//! This module contains the macros
+//! for creating choose functions for any number
+//! of participants.
+//!
+//! *This module is available only if MultiCrusty is built with
+//! the `"macros_multiple"` feature.*
 
 /// Create the *ChooseMpst* type to be used with more than 3 participants.
 ///
@@ -17,7 +21,11 @@
 /// create_meshedchannels!(MeshedChannels, 3);
 /// create_choose_type_multi!(ChooseMpstThree, MeshedChannels, 3);
 /// ```
+///
+/// *This macro is available only if MultiCrusty is built with
+/// the `"macros_multiple"` feature.*
 #[macro_export]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "macros_multiple")))]
 macro_rules! create_choose_type_multi {
     ($type_name: ident, $meshedchannels_name: ident, $nsessions: literal) => {
         mpst_seq::create_choose_type_multi!($type_name, $meshedchannels_name, $nsessions);
@@ -61,7 +69,11 @@ macro_rules! create_choose_type_multi {
 ///     3
 /// );
 /// ```
+///
+/// *This macro is available only if MultiCrusty is built with
+/// the `"macros_multiple"` feature.*
 #[macro_export]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "macros_multiple")))]
 macro_rules! create_choose_mpst_session_multi_left {
     (
         $func_name: ident,
@@ -119,7 +131,11 @@ macro_rules! create_choose_mpst_session_multi_left {
 ///     3
 /// );
 /// ```
+///
+/// *This macro is available only if MultiCrusty is built with
+/// the `"macros_multiple"` feature.*
 #[macro_export]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "macros_multiple")))]
 macro_rules! create_choose_mpst_session_multi_right {
     (
         $func_name: ident,
@@ -179,7 +195,11 @@ macro_rules! create_choose_mpst_session_multi_right {
 ///     3
 /// );
 /// ```
+///
+/// *This macro is available only if MultiCrusty is built with
+/// the `"macros_multiple"` feature.*
 #[macro_export]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "macros_multiple")))]
 macro_rules! create_choose_mpst_session_multi_both {
     (
         $func_name_left: ident,
@@ -258,7 +278,11 @@ macro_rules! create_choose_mpst_session_multi_both {
 ///    }
 /// }
 /// ```
+///
+/// *This macro is available only if MultiCrusty is built with
+/// the `"macros_multiple"` feature.*
 #[macro_export]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "macros_multiple")))]
 macro_rules! choose_mpst_multi_to_all {
     (
         $session: expr,
@@ -328,7 +352,11 @@ macro_rules! choose_mpst_multi_to_all {
 /// ```
 ///
 /// [`choose_mpst_multi_to_all`]: crate::choose_mpst_multi_to_all
+///
+/// *This macro is available only if MultiCrusty is built with
+/// the `"macros_multiple"` feature.*
 #[macro_export]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "macros_multiple")))]
 macro_rules! choose_mpst_create_multi_to_all {
     (
         $name: expr,
@@ -400,7 +428,6 @@ macro_rules! choose_mpst_create_multi_to_all {
 /// Available on the *cancel/cancel_8* test.
 ///
 /// ```compile_fail
-/// use mpstthree::role::Role;
 /// use mpstthree::{create_multiple_normal_role, create_meshedchannels, choose_mpst_multi_cancel_to_all};
 ///
 /// create_multiple_normal_role!(
@@ -440,7 +467,11 @@ macro_rules! choose_mpst_create_multi_to_all {
 ///    }
 /// }
 /// ```
+///
+/// *This macro is available only if MultiCrusty is built with
+/// the `"macros_multiple"` feature.*
 #[macro_export]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "macros_multiple")))]
 macro_rules! choose_mpst_multi_cancel_to_all {
     (
         $session: expr,
@@ -508,7 +539,11 @@ macro_rules! choose_mpst_multi_cancel_to_all {
 ///    }
 /// }
 /// ```
+///
+/// *This macro is available only if MultiCrusty is built with
+/// the `"macros_multiple"` feature.*
 #[macro_export]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "macros_multiple")))]
 macro_rules! choose_mpst_multi_http_to_all {
     (
         $session: expr,
@@ -563,7 +598,11 @@ macro_rules! choose_mpst_multi_http_to_all {
 ///     RoleC, MeshedChannelsThree, 3
 /// );
 /// ```
+///
+/// *This macro is available only if MultiCrusty is built with
+/// the `"macros_multiple"` feature.*
 #[macro_export]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "macros_multiple")))]
 macro_rules! create_fn_choose_mpst_multi_to_all_bundle {
     (
         $( $fn_name: ident , )+ =>
@@ -623,7 +662,11 @@ macro_rules! create_fn_choose_mpst_multi_to_all_bundle {
 ///     RoleA, RoleC, MeshedChannelsThree, 3
 /// );
 /// ```
+///
+/// *This macro is available only if MultiCrusty is built with
+/// the `"macros_multiple"` feature.*
 #[macro_export]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "macros_multiple")))]
 macro_rules! create_fn_choose_mpst_cancel_multi_to_all_bundle {
     (
         $( $fn_name: ident , )+ =>
