@@ -1,7 +1,11 @@
-////////////////////////////////////////////
-/// CHOOSE
+//! This module contains the macros
+//! for creating choose functions for three
+//! of participants, whatever are their name.
+//!
+//! *This module is available only if MultiCrusty is built with
+//! the `"macros_simple"` feature.*
 
-/// Create the core for the choose_mpst macros
+// Create the core for the choose_mpst macros
 #[macro_export]
 #[doc(hidden)]
 macro_rules! create_choose_from_1_to_2_3 {
@@ -242,7 +246,11 @@ macro_rules! create_choose_from_3_to_1_2 {
 /// ```
 ///
 /// [`MeshedChannels`]: crate::meshedchannels::MeshedChannels
+///
+/// *This macro is available only if MultiCrusty is built with
+/// the `"macros_simple"` feature.*
 #[macro_export]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "macros_simple")))]
 macro_rules! create_choose_right_from_3_to_1_and_2 {
     ($func_name: ident, $dual_1:ident, $dual_2:ident, $role_broadcast: ident, $sender: ident) => {
         fn $func_name<'a, S0, S1, S2, S3, S4, S5, R0, R1, R2, R3, R4, R5>(
@@ -345,7 +353,11 @@ macro_rules! create_choose_right_from_3_to_1_and_2 {
 /// ```
 ///
 /// [`MeshedChannels`]: crate::meshedchannels::MeshedChannels
+///
+/// *This macro is available only if MultiCrusty is built with
+/// the `"macros_simple"` feature.*
 #[macro_export]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "macros_simple")))]
 macro_rules! create_choose_left_from_3_to_1_and_2 {
     ($func_name: ident, $dual_1:ident, $dual_2:ident, $role_broadcast: ident, $sender: ident) => {
         fn $func_name<'a, S0, S1, S2, S3, S4, S5, R0, R1, R2, R3, R4, R5>(
@@ -448,7 +460,11 @@ macro_rules! create_choose_left_from_3_to_1_and_2 {
 /// ```
 ///
 /// [`MeshedChannels`]: crate::meshedchannels::MeshedChannels
+///
+/// *This macro is available only if MultiCrusty is built with
+/// the `"macros_simple"` feature.*
 #[macro_export]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "macros_simple")))]
 macro_rules! create_choose_left_from_1_to_2_and_3 {
     ($func_name: ident, $dual_1:ident, $dual_2:ident, $role_broadcast: ident, $sender: ident) => {
         fn $func_name<'a, S0, S1, S2, S3, S4, S5, R0, R1, R2, R3, R4, R5>(
@@ -551,7 +567,11 @@ macro_rules! create_choose_left_from_1_to_2_and_3 {
 /// ```
 ///
 /// [`MeshedChannels`]: crate::meshedchannels::MeshedChannels
+///
+/// *This macro is available only if MultiCrusty is built with
+/// the `"macros_simple"` feature.*
 #[macro_export]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "macros_simple")))]
 macro_rules! create_choose_right_from_1_to_2_and_3 {
     ($func_name: ident, $dual_1:ident, $dual_2:ident, $role_broadcast: ident, $sender: ident) => {
         fn $func_name<'a, S0, S1, S2, S3, S4, S5, R0, R1, R2, R3, R4, R5>(
@@ -654,7 +674,11 @@ macro_rules! create_choose_right_from_1_to_2_and_3 {
 /// ```
 ///
 /// [`MeshedChannels`]: crate::meshedchannels::MeshedChannels
+///
+/// *This macro is available only if MultiCrusty is built with
+/// the `"macros_simple"` feature.*
 #[macro_export]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "macros_simple")))]
 macro_rules! create_choose_left_from_2_to_1_and_3 {
     ($func_name: ident, $dual_1:ident, $dual_2:ident, $role_broadcast: ident, $sender: ident) => {
         fn $func_name<'a, S0, S1, S2, S3, S4, S5, R0, R1, R2, R3, R4, R5>(
@@ -757,7 +781,11 @@ macro_rules! create_choose_left_from_2_to_1_and_3 {
 /// ```
 ///
 /// [`MeshedChannels`]: crate::meshedchannels::MeshedChannels
+///
+/// *This macro is available only if MultiCrusty is built with
+/// the `"macros_simple"` feature.*
 #[macro_export]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "macros_simple")))]
 macro_rules! create_choose_right_from_2_to_1_and_3 {
     ($func_name: ident, $dual_1:ident, $dual_2:ident, $role_broadcast: ident, $sender: ident) => {
         fn $func_name<'a, S0, S1, S2, S3, S4, S5, R0, R1, R2, R3, R4, R5>(
@@ -864,7 +892,11 @@ macro_rules! create_choose_right_from_2_to_1_and_3 {
 /// [`MeshedChannels`]: crate::meshedchannels::MeshedChannels
 /// [create_choose_right_from_2_to_1_and_3]: crate::create_choose_right_from_2_to_1_and_3
 /// [create_choose_left_from_2_to_1_and_3]: crate::create_choose_left_from_2_to_1_and_3
+///
+/// *This macro is available only if MultiCrusty is built with
+/// the `"macros_simple"` feature.*
 #[macro_export]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "macros_simple")))]
 macro_rules! create_choose_both_from_2_to_1_and_3 {
     (
         $func_name_right: ident,
@@ -935,7 +967,11 @@ macro_rules! create_choose_both_from_2_to_1_and_3 {
 /// [`MeshedChannels`]: crate::meshedchannels::MeshedChannels
 /// [create_choose_right_from_1_to_2_and_3]: crate::create_choose_right_from_1_to_2_and_3
 /// [create_choose_left_from_1_to_2_and_3]: crate::create_choose_left_from_1_to_2_and_3
+///
+/// *This macro is available only if MultiCrusty is built with
+/// the `"macros_simple"` feature.*
 #[macro_export]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "macros_simple")))]
 macro_rules! create_choose_both_from_1_to_2_and_3 {
     (
         $func_name_right: ident,
@@ -1006,7 +1042,11 @@ macro_rules! create_choose_both_from_1_to_2_and_3 {
 /// [`MeshedChannels`]: crate::meshedchannels::MeshedChannels
 /// [create_choose_right_from_3_to_1_and_2]: crate::create_choose_right_from_3_to_1_and_2
 /// [create_choose_left_from_3_to_1_and_2]: crate::create_choose_left_from_3_to_1_and_2
+///
+/// *This macro is available only if MultiCrusty is built with
+/// the `"macros_simple"` feature.*
 #[macro_export]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "macros_simple")))]
 macro_rules! create_choose_both_from_3_to_1_and_2 {
     (
         $func_name_right: ident,
@@ -1078,7 +1118,11 @@ macro_rules! create_choose_both_from_3_to_1_and_2 {
 /// ```
 ///
 /// [`MeshedChannels`]: crate::meshedchannels::MeshedChannels
+///
+/// *This macro is available only if MultiCrusty is built with
+/// the `"macros_simple"` feature.*
 #[macro_export]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "macros_simple")))]
 macro_rules! choose_mpst_to_all {
     (
         $session: expr ,
