@@ -1,3 +1,6 @@
+//! The different associated functions for role B
+//! with only A, B and C in the protocol.
+
 use crate::binary::cancel::cancel;
 use crate::binary::send::send;
 use crate::binary::struct_trait::{end::End, recv::Recv, send::Send, session::Session};
@@ -24,6 +27,7 @@ type ResultType<T, S1, S2, R> = Result<(T, ReturnType<S1, S2, R>), Box<dyn Error
 impl<S1: Session, S2: Session, R: Role, T: marker::Send>
     MeshedChannels<Send<T, S1>, S2, RoleA<R>, RoleB<RoleEnd>>
 {
+    /// Send a payload of type T to role A
     pub fn send(self, payload: T) -> ReturnType<S1, S2, R> {
         send_aux_simple!(self, payload, RoleA, 1)
     }
@@ -32,6 +36,7 @@ impl<S1: Session, S2: Session, R: Role, T: marker::Send>
 impl<S1: Session, S2: Session, R: Role, T: marker::Send>
     MeshedChannels<S1, Send<T, S2>, RoleC<R>, RoleB<RoleEnd>>
 {
+    /// Send a payload of type T to role C
     pub fn send(self, payload: T) -> ReturnType<S1, S2, R> {
         send_aux_simple!(self, payload, RoleC, 2)
     }
@@ -40,6 +45,7 @@ impl<S1: Session, S2: Session, R: Role, T: marker::Send>
 impl<S1: Session, S2: Session, R: Role, T: marker::Send>
     MeshedChannels<Recv<T, S1>, S2, RoleA<R>, RoleB<RoleEnd>>
 {
+    /// Receive a payload from role A
     pub fn recv(self) -> ResultType<T, S1, S2, R> {
         recv_aux_simple!(self, RoleA, 1)()
     }
@@ -48,6 +54,7 @@ impl<S1: Session, S2: Session, R: Role, T: marker::Send>
 impl<S1: Session, S2: Session, R: Role, T: marker::Send>
     MeshedChannels<S1, Recv<T, S2>, RoleC<R>, RoleB<RoleEnd>>
 {
+    /// Receive a payload from role C
     pub fn recv(self) -> ResultType<T, S1, S2, R> {
         recv_aux_simple!(self, RoleC, 2)()
     }
@@ -56,6 +63,7 @@ impl<S1: Session, S2: Session, R: Role, T: marker::Send>
 impl<S1: Session, S2: Session, T: marker::Send>
     MeshedChannels<Recv<T, S1>, S2, RoleAlltoA<RoleEnd, RoleEnd>, RoleB<RoleEnd>>
 {
+    #[doc(hidden)]
     pub fn recv(self) -> ResultType<T, S1, S2, RoleEnd> {
         recv_all_aux_simple!(self, RoleAlltoA, 1)()
     }
@@ -64,6 +72,7 @@ impl<S1: Session, S2: Session, T: marker::Send>
 impl<S1: Session, S2: Session, T: marker::Send>
     MeshedChannels<S1, Recv<T, S2>, RoleAlltoC<RoleEnd, RoleEnd>, RoleB<RoleEnd>>
 {
+    #[doc(hidden)]
     pub fn recv(self) -> ResultType<T, S1, S2, RoleEnd> {
         recv_all_aux_simple!(self, RoleAlltoC, 2)()
     }
@@ -77,6 +86,7 @@ impl<'a, S1: Session, S2: Session, S3: Session, S4: Session, R1: Role, R2: Role>
         RoleB<RoleEnd>,
     >
 {
+    /// Receive a binary choice from role A
     pub fn offer<F, G, U>(self, f: F, g: G) -> Result<U, Box<dyn Error + 'a>>
     where
         F: FnOnce(MeshedChannels<S1, S2, R1, RoleB<RoleEnd>>) -> Result<U, Box<dyn Error + 'a>>,
@@ -96,6 +106,7 @@ impl<'a, S1: Session, S2: Session, S3: Session, S4: Session, R1: Role, R2: Role>
         RoleB<RoleEnd>,
     >
 {
+    /// Receive a binary choice from role C
     pub fn offer<F, G, U>(self, f: F, g: G) -> Result<U, Box<dyn Error + 'a>>
     where
         F: FnOnce(MeshedChannels<S1, S2, R1, RoleB<RoleEnd>>) -> Result<U, Box<dyn Error + 'a>>,
@@ -201,6 +212,7 @@ impl<
         RoleB<RoleEnd>,
     >
 {
+    /// Choose the right branch of a binary choice and send it to A and C
     pub fn choose_left(
         self,
     ) -> MeshedChannels<<S2 as Session>::Dual, <S3 as Session>::Dual, R4, RoleB<RoleEnd>> {
@@ -219,6 +231,7 @@ impl<
         )
     }
 
+    /// Choose the left branch of a binary choice and send it to A and C
     pub fn choose_right(
         self,
     ) -> MeshedChannels<<S4 as Session>::Dual, <S5 as Session>::Dual, R5, RoleB<RoleEnd>> {
@@ -239,6 +252,7 @@ impl<
 }
 
 impl MeshedChannels<End, End, RoleEnd, RoleB<RoleEnd>> {
+    /// Close the current connection
     pub fn close(self) -> Result<(), Box<dyn Error>> {
         close_mpst(self)
     }
