@@ -1,3 +1,7 @@
+//! This module contains the required definitions and
+//! functions for the basic role A.
+//! Its dual is [RoleADual](crate::role::a_dual::RoleADual).
+
 use crate::role::a_dual::RoleADual;
 use crate::role::Role;
 use crossbeam_channel::{bounded, Sender};
@@ -14,10 +18,13 @@ use crossbeam_channel::{bounded, Sender};
 /// # Example
 ///
 /// ```
+/// use mpstthree::role::Role; // Only used for example
 /// use mpstthree::role::a::RoleA;
 /// use mpstthree::role::end::RoleEnd;
 ///
 /// type NameA = RoleA<RoleEnd>;
+///
+/// let _ = NameA::new(); // Only used for example
 /// ```
 #[derive(Debug)]
 pub struct RoleA<R>
@@ -25,6 +32,7 @@ where
     R: Role,
     R::Dual: Role,
 {
+    #[doc(hidden)]
     pub sender: Sender<R::Dual>,
 }
 
