@@ -1,3 +1,7 @@
+//! This module contains the required definitions and
+//! functions for the basic role C.
+//! Its dual is [RoleCDual](crate::role::c_dual::RoleCDual).
+
 use crate::role::c_dual::RoleCDual;
 use crate::role::Role;
 use crossbeam_channel::{bounded, Sender};
@@ -9,15 +13,18 @@ use crossbeam_channel::{bounded, Sender};
 /// of the [`MeshedChannels`] related
 /// to C.
 ///
-/// [`MeshedChannels`]: RoleBroadcastmeshedchannels/struct.MeshedChannels.html
+/// [`MeshedChannels`]: crate::meshedchannels::MeshedChannels
 ///
 /// # Example
 ///
 /// ```
+/// use mpstthree::role::Role; // Only used for example
 /// use mpstthree::role::c::RoleC;
 /// use mpstthree::role::end::RoleEnd;
 ///
 /// type NameC = RoleC<RoleEnd>;
+///
+/// let _ = NameC::new(); // Only used for example
 /// ```
 #[derive(Debug)]
 pub struct RoleC<R>
@@ -25,6 +32,7 @@ where
     R: Role,
     R::Dual: Role,
 {
+    #[doc(hidden)]
     pub sender: Sender<R::Dual>,
 }
 
